/**********************************************************************************/
/*    Demo program for:								  */
/*	  Board: MSP430-GBD     						  */
/*    Manufacture: OLIMEX                                                   	  */
/*	  COPYRIGHT (C) 2009							  */
/*    Designed by: Engineer Penko T. Bozhkov                                      */
/*    Module Name    :  main module                                               */
/*    File   Name    :  main.c                                                    */
/*    Revision       :  initial                                                   */
/*    Date           :  11.03.2010                                                */
/**********************************************************************************/
#include "msp430x22x4.h"
#include <intrinsics.h>

void Ports_initial_initialization(void);
void init_devices(void);

#define Buzzer_ON                  P3OUT |= 0x80;  P1DIR |= 0x80;
#define Buzzer_OFF                 P3OUT &= ~0x80; P1DIR |= 0x80;
#define Buzzer_Check              (P3IN & 0x80)


/**********************************************************************************/
/*  Function name: Ports_initial_initialization                                   */
/*  	Parameters                                                                */
/*          Input   :  No	                                                  */
/*          Output  :  No	                                                  */
/*	Action: Define initial ports states and directions.			  */
/**********************************************************************************/
void Ports_initial_initialization(void)
{
   //input_data=P1IN;          //Read only register
  P1OUT = 0x00;               // The outputs are low
  P1SEL = 0x00;               // Peripheral module function: I/O function is selected.
  P1DIR = 0x01;               // 1 -> Output; 0 -> Input; All inputs except LED 
  P1REN = 0x00;               // Pullup/pulldown resistor disabled
  P1IES = 0x00;               // Interrupt Edge Select Registers
  P1IE = 0x00;                // Disable all PORTx interrupts
  P1IFG = 0x00;               // Clear all interrupt flags

   //input_data=P2IN;          //Read only register
  P2OUT = 0x00;               // The outputs are low
  P2SEL = 0x00;               // Peripheral module function: I/O function is selected.
  P2DIR = 0x01;               // 1 -> Output; 0 -> Input
  P2REN = 0x00;               // Pullup/pulldown resistor disabled
  P2IES = 0x00;               // Interrupt Edge Select Registers
  P2IE = 0x00;                // Disable all PORTx interrupts
  P2IFG = 0x00;               // Clear all interrupt flags

   //input_data=P3IN;          //Read only register
  P3OUT = 0x00;               // The outputs are low
  P3SEL = 0x30;               // Peripheral module function: enabled for UCA0TXD and UCA0RXD
  P3DIR = 0x90;               // 1 -> Output; 0 -> Input; UCA0TXD output, Buzz output
  P3REN = 0x00;               // Pullup/pulldown resistor disabled

  //input_data=P4IN;          //Read only register
  P4OUT = 0x00;               // The outputs are low
  P4SEL = 0x00;               // Peripheral module function: I/O function is selected.
  P4DIR = 0x01;               // 1 -> Output; 0 -> Input;
  P4REN = 0x00;               // Pullup/pulldown resistor disabled
}


/**********************************************************************************/
/*  Function name: init_devices	                                                  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Initialize all used MSP430F2274 peripheral devices.	  	  */
/**********************************************************************************/
void init_devices(void){
  _BIC_SR(GIE); // Disable interrupts during initialization process
  
  /********** 1.Ports initialization ***********/
  Ports_initial_initialization();
  /********** 2.Peripherals initialization ***********/
  //2.0. Set system clock:
  BCSCTL1 = CALBC1_1MHZ;                    // Set DCO
  DCOCTL = CALDCO_1MHZ;
  
  // 2.1. Timer_A
  // =============
  TACTL = 0x0004;   // Timer_A clear
  TACCTL0 = 0x0010; // Timer_A Capture/compare interrupt enable
  TACCR0 = 0x000F;  // Set TACCR0 value: 1MHz / 8 = 125kHz; 125kHz / 15 = 8.33kHz
  TACTL = 0x02D0;   // Selected: SMCLK, divider 1/8, Up mode

  _BIS_SR(GIE); // Global Interrupt enabled. Do this at the END of the initialization!!!!!!!!
}


/**********************************************************************************/
/*  Function name: main	                                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Call "init_devices()" and then loop forever.	  		  */
/**********************************************************************************/
void main(void)
{
    WDTCTL = WDTPW + WDTHOLD;               // Stop watchdog timer
    init_devices();
    while(1){
     
  } 
}


/**********************************************************************************/
/*  Function name: TIMERA_Capture_Compare_ISR                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Switch over T1 transistor and thus lead Buzzer to beep.           */
/**********************************************************************************/
#pragma vector=TIMERA0_VECTOR
__interrupt void TIMER_ISR(void)
{
  // Buzzer resonance frequency is 4.1kHz, TimerA CCR frequency is set to 8.33kHz
  if(Buzzer_Check ){
    Buzzer_OFF;
  }
  else{
    Buzzer_ON;
  }

}

